
# WuttaPOS

This project includes two primary components:

- web app and related daemons, to run on the server
- standalone GUI app, to run on the lanes

This project is in the very early stages and is not yet documented.
It is based on an earlier effort, which used Rattail:
[rattail/wuttapos](https://forgejo.wuttaproject.org/rattail/wuttapos)

However this project uses Wutta Framework, has no Rattail
dependencies, and "starts over" for (mostly) everything.


## Server

Make a virtual environment and install the app:

    python3 -m venv wuttapos
    source wuttapos/bin/activate
    pip install WuttaPOS[server]
    wuttapos install

For more info see
https://docs.wuttaproject.org/wuttjamaican/narr/install/index.html


## Terminal

It uses [Flet](https://flet.dev/) for the GUI toolkit.  The intended
use case is to run as a proper standalone GUI app on the lane desktop.

Flet has yet to reach a stable 1.0 version, although it's getting
close.  Some things have changed since this GUI app project first
began, and it needs refactoring to support newer Flet.  It currently
is pinning an older version so the code at least works.

So far, there is no installer per se.  For development purpose you can
install the server (above) and then within that same virtual
environment:

    pip install WuttaPOS[terminal]

The terminal and server apps will share the same database.  The terminal
probably requires more setup than just that, needs to be documented...

To launch the terminal app in GUI mode:

    wuttapos run

To run the terminal as a web server:

    wuttapos serve
